@@ -4,10 +4,11 @@ import time
 from scape.action.executor import Executor
 from scape.conf.settings import INNER_EXECUTORS
 from scape.action.action import Action, CompoundAction, ActionFactory
+from scape.stream.action_stream import ActionStream
 
 
 class Dispatcher(multiprocessing.Process, Executor):
-    def __init__(self, executors, action_queue, lock):
+    def __init__(self, executors, action_stream, lock, stream_info):
         super().__init__()
         self.executors = {}
         for executor in executors:
@@ -15,9 +16,10 @@ class Dispatcher(multiprocessing.Process, Executor):
             module = importlib.import_module(module)
             executor = getattr(module, executor)()
             self.executors[executor.__class__.__name__] = executor
-        self.action_queue = action_queue
+        self.action_stream = action_stream
         self.lock = lock
         self.action = None
+        self.stream_info = stream_info
 
     def execute(self, action):
         executor = action.get_processor_name()
@@ -27,8 +29,10 @@ class Dispatcher(multiprocessing.Process, Executor):
 
     def run(self):
         while True:
+            if self.stream_info['current_stream'] is not self.action_stream:
+                self.action_stream = self.stream_info['current_stream']
             if self.action is None:
-                self.action = self.action_queue.get()
+                self.action = self.action_stream.get()
             if isinstance(self.action, Action):
                 self.execute(self.action)
                 self.lock.acquire()
@@ -38,7 +42,7 @@ class Dispatcher(multiprocessing.Process, Executor):
                 object_parallel = self.action.deserialize()
                 self.action = object_parallel[0][0]
                 for action_group in object_parallel[1:]:
-                    self.action_queue.put(action_group[0])
+                    self.action_stream.put(action_group[0])
 
 
 class DispatchPool:
@@ -56,45 +60,30 @@ class DispatchPool:
             module = importlib.import_module(module)
             executor = getattr(module, executor)()
             self.inner_executors[executor.__class__.__name__] = executor
-        self.action_queue = multiprocessing.Queue(pool_size)
+        self.action_stream = ActionStream()
+        self.stream_info = {'current_stream': self.action_stream}
         for index in range(pool_size):
-            dispatcher = Dispatcher(executors, self.action_queue, multiprocessing.Lock())
+            dispatcher = Dispatcher(executors, self.action_stream, multiprocessing.Lock(), self.stream_info)
             dispatcher.daemon = True
             dispatcher.start()
-        self.record_actions = None
-        self.record = False
-        self.begin_time = None
-        self.end_time = None
 
     @classmethod
     def get_instance(cls):
         return cls.__instance
 
-    def start_record(self):
-        self.record = True
-
-    def stop_record(self, compound_action):
-        self.record = False
-        self.begin_time = None
-        compound_action.add_group(*self.record_actions)
-        self.record_actions = None
-        return compound_action
-
     def process(self, action):
         if isinstance(action, Action):
             executor = action.get_processor_name()
             if executor in self.inner_executors.keys():
-                self.inner_executors[executor].execute(action)
-                return
-        if self.record:
-            self.end_time = time.time()
-            if self.begin_time is not None:
-                self.record_actions.append(ActionFactory.make('Delayer.delay', (self.end_time - self.begin_time,)))
-            self.record_actions.append(action)
+                return self.inner_executors[executor].execute(action)
         if isinstance(action, Action):
-            self.action_queue.put(action)
+            self.action_stream.put(action)
         elif isinstance(action, CompoundAction):
             for action_group in action.deserialize():
-                self.action_queue.put(action_group[0])
-        if self.record and self.begin_time is None:
-            self.begin_time = time.time()
+                self.action_stream.put(action_group[0])
+
+    def change_stream(self, new_stream):
+        self.stream_info['current_stream'] = new_stream
+
+    def get_current_stream(self):
+        return self.stream_info['current_stream']
